@@ -40,7 +40,7 @@ see https://www.gnu.org/licenses/.  */
 #if ! defined (__GMP_WITHIN_CONFIGURE)
 #define __GMP_HAVE_HOST_CPU_FAMILY_power   0
 #define __GMP_HAVE_HOST_CPU_FAMILY_powerpc 0
-#define GMP_LIMB_BITS                      64
+#define GMP_LIMB_BITS                      32
 #define GMP_NAIL_BITS                      0
 #endif
 #define GMP_NUMB_BITS     (GMP_LIMB_BITS - GMP_NAIL_BITS)
@@ -57,7 +57,7 @@ see https://www.gnu.org/licenses/.  */
 
 /* Instantiated by configure. */
 #if ! defined (__GMP_WITHIN_CONFIGURE)
-#define _LONG_LONG_LIMB 1
+/* #undef _LONG_LONG_LIMB */
 #define __GMP_LIBGMP_DLL  1
 #endif
 
@@ -2324,12 +2324,12 @@ enum
 
 /* Define CC and CFLAGS which were used to build this version of GMP */
 #define __GMP_CC "gcc"
-#define __GMP_CFLAGS "-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -Wno-attributes -fdebug-prefix-map=/mnt/share/cygpkgs/gmp/gmp.x86_64/build=/usr/src/debug/gmp-6.2.0-2 -fdebug-prefix-map=/mnt/share/cygpkgs/gmp/gmp.x86_64/src/gmp-6.2.0=/usr/src/debug/gmp-6.2.0-2"
+#define __GMP_CFLAGS "-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -Wno-attributes -fdebug-prefix-map=/mnt/share/cygpkgs/gmp/gmp.x86/build=/usr/src/debug/gmp-6.2.1-1 -fdebug-prefix-map=/mnt/share/cygpkgs/gmp/gmp.x86/src/gmp-6.2.1=/usr/src/debug/gmp-6.2.1-1"
 
 /* Major version number is the value of __GNU_MP__ too, above. */
 #define __GNU_MP_VERSION            6
 #define __GNU_MP_VERSION_MINOR      2
-#define __GNU_MP_VERSION_PATCHLEVEL 0
+#define __GNU_MP_VERSION_PATCHLEVEL 1
 #define __GNU_MP_RELEASE (__GNU_MP_VERSION * 10000 + __GNU_MP_VERSION_MINOR * 100 + __GNU_MP_VERSION_PATCHLEVEL)
 
 #define __GMP_H__
